@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -50,7 +50,7 @@ public:
     SKGObjectModel(SKGDocumentBank* iDocument,
                    const QString& iTable,
                    const QString& iWhereClause,
-                   QObject *parent = NULL,
+                   QWidget* parent = NULL,
                    const QString& iParentAttribute = "",
                    bool iResetOnCreation = true);
 
@@ -65,7 +65,7 @@ public:
      * @param role the role
      * @return the returned value
      */
-    virtual QVariant data(const QModelIndex & index, int role = Qt::DisplayRole) const;
+    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
 
     /**
      * Sets the role data for the item at index to value. Returns true if successful; otherwise returns false.
@@ -74,7 +74,7 @@ public:
      * @param role role
      * @return
      */
-    virtual bool setData(const QModelIndex & index, const QVariant & value, int role = Qt::EditRole);
+    virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);
 
     /**
      * Returns the data for the given role and section in the header with the specified orientation.
@@ -90,7 +90,7 @@ public:
      * @param index index of the object
      * @return flags of the given index
      */
-    virtual Qt::ItemFlags flags(const QModelIndex &index) const;
+    virtual Qt::ItemFlags flags(const QModelIndex& index) const;
 
     /**
      * Returns the actions supported by the data in this model.
@@ -116,10 +116,10 @@ public:
      * @param parent parent
      * @return true if the dropping was successful otherwise false.
      */
-    virtual bool dropMimeData(const QMimeData *data,
+    virtual bool dropMimeData(const QMimeData* data,
                               Qt::DropAction action,
                               int row, int column,
-                              const QModelIndex &parent);
+                              const QModelIndex& parent);
 
 protected Q_SLOTS:
     /**
@@ -135,6 +135,14 @@ protected Q_SLOTS:
      */
     virtual void dataModified(const QString& iTableName, int iIdTransaction);
 
+    /**
+     * Get the attribute value for grouping
+     * @param iObject the object
+     * @param iAttribute the attribute name
+     * @return the value of the attribute
+     */
+    virtual QString getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const;
+
 private:
     Q_DISABLE_COPY(SKGObjectModel);
 
@@ -157,9 +165,9 @@ private:
     QVariant m_fontFutureOperationsColor;
     QVariant m_fontNotValidatedOperationsColor;
     QVariant m_fontSubOperationsColor;
-    QVariant m_fontRedColor;
 
     QVariant m_iconTransfer;
+    QVariant m_iconGroup;
     QVariant m_iconSplit;
     QVariant m_iconMuchMore;
     QVariant m_iconMuchLess;
