@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -33,11 +33,11 @@
 #include <QCheckBox>
 #include <QApplication>
 
-SKGPredicatCreator::SKGPredicatCreator(QWidget *parent, SKGDocument* document, const QString& attribute, bool iModeUpdate, const QStringList& iListAtt)
+SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, const QString& attribute, bool iModeUpdate, const QStringList& iListAtt)
     : QWidget(parent), m_updateMode(iModeUpdate), m_kValue1(NULL), m_kValue2(NULL), m_kAttributes(NULL)
 {
     SKGServices::AttributeType attType = SKGServices::TEXT;
-    if(document) attType = document->getAttributeType(attribute);
+    if (document) attType = document->getAttributeType(attribute);
     bool editable = !iModeUpdate || attribute.toLower() == attribute;
 
     //Build
@@ -49,7 +49,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget *parent, SKGDocument* document, c
     horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
     m_kOperator = new SKGComboBox(this);
     m_kOperator->setObjectName(QString::fromUtf8("kOperator"));
-    m_kOperator->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
+    m_kOperator->setSizeAdjustPolicy(KComboBox::AdjustToContentsOnFirstShow);
     QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     sizePolicy.setHorizontalStretch(0);
     sizePolicy.setVerticalStretch(0);
@@ -58,9 +58,9 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget *parent, SKGDocument* document, c
 
     horizontalLayout->addWidget(m_kOperator);
     int nbAtt = iListAtt.count();
-    if(nbAtt) {
+    if (nbAtt) {
         m_kAttributes = new SKGComboBox(this);
-        if(m_kAttributes) {
+        if (m_kAttributes) {
             m_kAttributes->setObjectName(QString::fromUtf8("kAttributes"));
             m_kAttributes->setMinimumSize(QSize(100, 0));
             m_kAttributes->setEditable(false);
@@ -73,13 +73,13 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget *parent, SKGDocument* document, c
             horizontalLayout->addWidget(m_kAttributes);
 
             foreach(const QString & att, iListAtt) {
-                if(document) m_kAttributes->addItem(document->getIcon(att), document->getDisplay(att), att);
+                if (document) m_kAttributes->addItem(document->getIcon(att), document->getDisplay(att), att);
             }
         }
     }
-    if(attType == SKGServices::TEXT) {
+    if (attType == SKGServices::TEXT) {
         SKGComboBox* cmbVal1 = new SKGComboBox(this);
-        if(cmbVal1) {
+        if (cmbVal1) {
             cmbVal1->setObjectName(QString::fromUtf8("cmbVal1"));
             cmbVal1->setMinimumSize(QSize(100, 0));
             cmbVal1->setEditable(editable);
@@ -93,7 +93,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget *parent, SKGDocument* document, c
             m_kValue1 = cmbVal1;
         }
         SKGComboBox* cmbVal2 = new SKGComboBox(this);
-        if(cmbVal2) {
+        if (cmbVal2) {
             cmbVal2->setObjectName(QString::fromUtf8("cmbVal2"));
             cmbVal2->setMinimumSize(QSize(100, 0));
             cmbVal2->setEditable(editable);
@@ -107,33 +107,33 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget *parent, SKGDocument* document, c
             m_kValue2 = cmbVal2;
         }
 
-        if(document) {
+        if (document) {
             QString realTable = "operation";
             QString realAtt = attribute;
             QString realCond = "";
-            if(attribute == "t_REALCATEGORY") {
+            if (attribute == "t_REALCATEGORY") {
                 realTable = "category";
                 realAtt = "t_fullname";
-            } else if(attribute == "t_ACCOUNT") {
+            } else if (attribute == "t_ACCOUNT") {
                 realTable = "account";
                 realAtt = "t_name";
-            } else if(attribute == "t_REALREFUND") {
+            } else if (attribute == "t_REALREFUND") {
                 realTable = "refund";
                 realAtt = "t_name";
-            } else if(attribute == "t_PAYEE") {
+            } else if (attribute == "t_PAYEE") {
                 realTable = "payee";
                 realAtt = "t_name";
-            } else if(attribute.startsWith(QLatin1String("p_"))) {
+            } else if (attribute.startsWith(QLatin1String("p_"))) {
                 realTable = "parameters";
                 realAtt = "t_value";
-                realCond = "t_name='" + attribute.right(attribute.length() - 2) + '\'';
+                realCond = "t_name='" % attribute.right(attribute.length() - 2) % '\'';
             }
             SKGMainPanel::fillWithDistinctValue(cmbVal1, document, realTable, realAtt, realCond);
             SKGMainPanel::fillWithDistinctValue(cmbVal2, document, realTable, realAtt, realCond);
         }
-    } else  if(attType == SKGServices::INTEGER || attType == SKGServices::FLOAT) {
+    } else  if (attType == SKGServices::INTEGER || attType == SKGServices::FLOAT) {
         SKGCalculatorEdit* cmbVal1 = new SKGCalculatorEdit(this);
-        if(cmbVal1) {
+        if (cmbVal1) {
             cmbVal1->setObjectName(QString::fromUtf8("cmbVal1"));
             cmbVal1->setMode(SKGCalculatorEdit::EXPRESSION);
             cmbVal1->setMinimumSize(QSize(100, 0));
@@ -142,7 +142,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget *parent, SKGDocument* document, c
             m_kValue1 = cmbVal1;
         }
         SKGCalculatorEdit* cmbVal2 = new SKGCalculatorEdit(this);
-        if(cmbVal2) {
+        if (cmbVal2) {
             cmbVal2->setObjectName(QString::fromUtf8("cmbVal2"));
             cmbVal2->setMode(SKGCalculatorEdit::EXPRESSION);
             cmbVal2->setMinimumSize(QSize(100, 0));
@@ -150,9 +150,9 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget *parent, SKGDocument* document, c
             horizontalLayout->addWidget(cmbVal2);
             m_kValue2 = cmbVal2;
         }
-    } else  if(attType == SKGServices::DATE) {
+    } else  if (attType == SKGServices::DATE) {
         SKGDateEdit* cmbVal1 = new SKGDateEdit(this);
-        if(cmbVal1) {
+        if (cmbVal1) {
             cmbVal1->setObjectName(QString::fromUtf8("cmbVal1"));
             cmbVal1->setMinimumSize(QSize(100, 0));
 
@@ -160,16 +160,16 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget *parent, SKGDocument* document, c
             m_kValue1 = cmbVal1;
         }
         SKGDateEdit* cmbVal2 = new SKGDateEdit(this);
-        if(cmbVal2) {
+        if (cmbVal2) {
             cmbVal2->setObjectName(QString::fromUtf8("cmbVal2"));
             cmbVal2->setMinimumSize(QSize(100, 0));
 
             horizontalLayout->addWidget(cmbVal2);
             m_kValue2 = cmbVal2;
         }
-    } else  if(attType == SKGServices::BOOL || attType == SKGServices::TRISTATE) {
+    } else  if (attType == SKGServices::BOOL || attType == SKGServices::TRISTATE) {
         QCheckBox* cmbVal1 = new QCheckBox(this);
-        if(cmbVal1) {
+        if (cmbVal1) {
             cmbVal1->setObjectName(QString::fromUtf8("cmbVal1"));
             cmbVal1->setMinimumSize(QSize(100, 0));
             cmbVal1->setTristate(attType == SKGServices::TRISTATE);
@@ -183,15 +183,15 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget *parent, SKGDocument* document, c
     m_kOperator->clear();
     m_kOperator->addItem("" , "");
 
-    if(m_kValue1) m_kValue1->installEventFilter(this);
-    if(m_kValue2) m_kValue2->installEventFilter(this);
-    if(m_kOperator) m_kOperator->installEventFilter(this);
-    if(m_kAttributes) m_kAttributes->installEventFilter(this);
+    if (m_kValue1) m_kValue1->installEventFilter(this);
+    if (m_kValue2) m_kValue2->installEventFilter(this);
+    if (m_kOperator) m_kOperator->installEventFilter(this);
+    if (m_kAttributes) m_kAttributes->installEventFilter(this);
 
     QStringList listOps = SKGRuleObject::getListOfOperators(attType, m_updateMode ? SKGRuleObject::UPDATE : SKGRuleObject::SEARCH);
     int nb = listOps.count();
-    if(!editable && nb > 1) nb = 1;
-    for(int i = 0; i < nb; ++i) {
+    if (!editable && nb > 1) nb = 1;
+    for (int i = 0; i < nb; ++i) {
         QString op = listOps.at(i);
         QString nlsOp = SKGRuleObject::getDisplayForOperator(op,
                         i18nc("Default value", "..."),
@@ -214,17 +214,17 @@ SKGPredicatCreator::~SKGPredicatCreator()
     m_kAttributes = NULL;
 }
 
-bool SKGPredicatCreator::eventFilter(QObject *object, QEvent *event)
+bool SKGPredicatCreator::eventFilter(QObject* object, QEvent* event)
 {
     Q_UNUSED(object);
-    if(event && (event->type() == QEvent::FocusIn || event->type() == QEvent::FocusOut)) {
+    if (event && (event->type() == QEvent::FocusIn || event->type() == QEvent::FocusOut)) {
         QObject* appliFocus = QApplication::focusWidget();
 
-        while(appliFocus) {
-            if(appliFocus == this) break;
+        while (appliFocus) {
+            if (appliFocus == this) break;
             appliFocus = appliFocus->parent();
         }
-        if(!appliFocus) Q_EMIT editingFinished();
+        if (!appliFocus) Q_EMIT editingFinished();
     }
     return false;
 }
@@ -232,10 +232,10 @@ bool SKGPredicatCreator::eventFilter(QObject *object, QEvent *event)
 void SKGPredicatCreator::onOperatorChanged()
 {
     QString req;
-    if(m_kOperator) req = m_kOperator->itemData(m_kOperator->currentIndex()).toString();
-    if(m_kValue1) m_kValue1->setVisible(req.contains("#V1S#") || req.contains("#V1#"));
-    if(m_kValue2) m_kValue2->setVisible(req.contains("#V2S#") || req.contains("#V2#"));
-    if(m_kAttributes) m_kAttributes->setVisible(req.contains("#ATT2#"));
+    if (m_kOperator) req = m_kOperator->itemData(m_kOperator->currentIndex()).toString();
+    if (m_kValue1) m_kValue1->setVisible(req.contains("#V1S#") || req.contains("#V1#"));
+    if (m_kValue2) m_kValue2->setVisible(req.contains("#V2S#") || req.contains("#V2#"));
+    if (m_kAttributes) m_kAttributes->setVisible(req.contains("#ATT2#"));
 }
 
 QString SKGPredicatCreator::text()
@@ -258,27 +258,27 @@ QString SKGPredicatCreator::getTextFromXml(const QString& iXML)
 QString SKGPredicatCreator::xmlDescription()
 {
     QString output;
-    if(m_kOperator) {
+    if (m_kOperator) {
         QString op = m_kOperator->itemData(m_kOperator->currentIndex()).toString();
-        if(!op.isEmpty()) {
+        if (!op.isEmpty()) {
             QDomDocument doc("SKGML");
             QDomElement root = doc.createElement("element");
             doc.appendChild(root);
 
             //Condition
             root.setAttribute("operator", op);
-            if(m_kValue1 && m_kValue1->isVisible()) {
-                SKGDateEdit *cmbVal1 = qobject_cast<SKGDateEdit *> (m_kValue1);
-                if(cmbVal1)  root.setAttribute("value", SKGServices::dateToSqlString(QDateTime(cmbVal1->date())));
+            if (m_kValue1 && m_kValue1->isVisible()) {
+                SKGDateEdit* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
+                if (cmbVal1)  root.setAttribute("value", SKGServices::dateToSqlString(QDateTime(cmbVal1->date())));
                 else {
-                    SKGCalculatorEdit *cmbVal1 = qobject_cast<SKGCalculatorEdit *> (m_kValue1);
-                    if(cmbVal1)  root.setAttribute("value", cmbVal1->text());
+                    SKGCalculatorEdit* cmbVal1 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
+                    if (cmbVal1)  root.setAttribute("value", cmbVal1->text());
                     else {
-                        QCheckBox *cmbVal1 = qobject_cast<QCheckBox *> (m_kValue1);
-                        if(cmbVal1)  root.setAttribute("value", cmbVal1->checkState() == Qt::Checked ? "Y" : cmbVal1->checkState() == Qt::Unchecked ? "N" : "P");
+                        QCheckBox* cmbVal1 = qobject_cast<QCheckBox*> (m_kValue1);
+                        if (cmbVal1)  root.setAttribute("value", cmbVal1->checkState() == Qt::Checked ? "Y" : cmbVal1->checkState() == Qt::Unchecked ? "N" : "P");
                         else {
-                            SKGComboBox *cmbVal1 = qobject_cast<SKGComboBox *> (m_kValue1);
-                            if(cmbVal1) root.setAttribute("value", cmbVal1->text());
+                            SKGComboBox* cmbVal1 = qobject_cast<SKGComboBox*> (m_kValue1);
+                            if (cmbVal1) root.setAttribute("value", cmbVal1->text());
                         }
                     }
 
@@ -286,20 +286,20 @@ QString SKGPredicatCreator::xmlDescription()
                 }
 
             }
-            if(m_kValue2 && m_kValue2->isVisible()) {
-                SKGDateEdit *cmbVal2 = qobject_cast<SKGDateEdit *> (m_kValue2);
-                if(cmbVal2)  root.setAttribute("value2", SKGServices::dateToSqlString(QDateTime(cmbVal2->date())));
+            if (m_kValue2 && m_kValue2->isVisible()) {
+                SKGDateEdit* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
+                if (cmbVal2)  root.setAttribute("value2", SKGServices::dateToSqlString(QDateTime(cmbVal2->date())));
                 else {
-                    SKGCalculatorEdit *cmbVal2 = qobject_cast<SKGCalculatorEdit *> (m_kValue2);
-                    if(cmbVal2)  root.setAttribute("value2", cmbVal2->text());
+                    SKGCalculatorEdit* cmbVal2 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
+                    if (cmbVal2)  root.setAttribute("value2", cmbVal2->text());
                     else {
-                        SKGComboBox *cmbVal2 = qobject_cast<SKGComboBox *> (m_kValue2);
-                        if(cmbVal2)  root.setAttribute("value2", cmbVal2->text());
+                        SKGComboBox* cmbVal2 = qobject_cast<SKGComboBox*> (m_kValue2);
+                        if (cmbVal2)  root.setAttribute("value2", cmbVal2->text());
                     }
                 }
             }
 
-            if(m_kAttributes && m_kAttributes->isVisible()) {
+            if (m_kAttributes && m_kAttributes->isVisible()) {
                 root.setAttribute("att2", m_kAttributes->itemData(m_kAttributes->currentIndex()).toString());
                 root.setAttribute("att2s", m_kAttributes->text());
             }
@@ -317,34 +317,34 @@ void SKGPredicatCreator::setXmlDescription(const QString& iXML)
     QDomElement root = doc.documentElement();
 
     //Condition
-    if(m_kOperator) {
+    if (m_kOperator) {
         m_kOperator->setCurrentIndex(m_kOperator->findData(root.attribute("operator")));
-        SKGDateEdit *cmbVal1 = qobject_cast<SKGDateEdit *> (m_kValue1);
-        if(cmbVal1)  cmbVal1->setDate(SKGServices::stringToTime(root.attribute("value")).date());
+        SKGDateEdit* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
+        if (cmbVal1)  cmbVal1->setDate(SKGServices::stringToTime(root.attribute("value")).date());
         else {
-            SKGCalculatorEdit *cmbVal1 = qobject_cast<SKGCalculatorEdit *> (m_kValue1);
-            if(cmbVal1)  cmbVal1->setText(root.attribute("value"));
+            SKGCalculatorEdit* cmbVal1 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
+            if (cmbVal1)  cmbVal1->setText(root.attribute("value"));
             else {
-                QCheckBox *cmbVal1 = qobject_cast<QCheckBox *> (m_kValue1);
-                if(cmbVal1)  cmbVal1->setCheckState(root.attribute("value") == "Y" ? Qt::Checked : root.attribute("value") == "P" ? Qt::PartiallyChecked : Qt::Unchecked);
+                QCheckBox* cmbVal1 = qobject_cast<QCheckBox*> (m_kValue1);
+                if (cmbVal1)  cmbVal1->setCheckState(root.attribute("value") == "Y" ? Qt::Checked : root.attribute("value") == "P" ? Qt::PartiallyChecked : Qt::Unchecked);
                 else {
-                    SKGComboBox *cmbVal1 = qobject_cast<SKGComboBox *> (m_kValue1);
-                    if(cmbVal1)  cmbVal1->setText(root.attribute("value"));
+                    SKGComboBox* cmbVal1 = qobject_cast<SKGComboBox*> (m_kValue1);
+                    if (cmbVal1)  cmbVal1->setText(root.attribute("value"));
                 }
             }
         }
-        SKGDateEdit *cmbVal2 = qobject_cast<SKGDateEdit *> (m_kValue2);
-        if(cmbVal2)  cmbVal2->setDate(SKGServices::stringToTime(root.attribute("value2")).date());
+        SKGDateEdit* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
+        if (cmbVal2)  cmbVal2->setDate(SKGServices::stringToTime(root.attribute("value2")).date());
         else {
-            SKGCalculatorEdit *cmbVal2 = qobject_cast<SKGCalculatorEdit *> (m_kValue2);
-            if(cmbVal2)  cmbVal2->setText(root.attribute("value2"));
+            SKGCalculatorEdit* cmbVal2 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
+            if (cmbVal2)  cmbVal2->setText(root.attribute("value2"));
             else {
-                SKGComboBox *cmbVal2 = qobject_cast<SKGComboBox *> (m_kValue2);
-                if(cmbVal2) cmbVal2->setText(root.attribute("value2"));
+                SKGComboBox* cmbVal2 = qobject_cast<SKGComboBox*> (m_kValue2);
+                if (cmbVal2) cmbVal2->setText(root.attribute("value2"));
             }
         }
 
-        if(m_kAttributes) {
+        if (m_kAttributes) {
             m_kAttributes->setCurrentIndex(m_kAttributes->findData(root.attribute("att2")));
         }
     }
