@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -42,14 +42,14 @@ SKGCategoryObject::SKGCategoryObject(const SKGCategoryObject& iObject)
 SKGCategoryObject::SKGCategoryObject(const SKGObjectBase& iObject)
 
 {
-    if(iObject.getRealTable() == "category") {
+    if (iObject.getRealTable() == "category") {
         copyFrom(iObject);
     } else {
         *this = SKGNamedObject(iObject.getDocument(), "v_category", iObject.getID());
     }
 }
 
-const SKGCategoryObject& SKGCategoryObject::operator= (const SKGObjectBase & iObject)
+const SKGCategoryObject& SKGCategoryObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -58,7 +58,7 @@ const SKGCategoryObject& SKGCategoryObject::operator= (const SKGObjectBase & iOb
 SKGError SKGCategoryObject::setName(const QString& iName)
 {
     SKGError err;
-    if(iName.contains(OBJECTSEPARATOR)) err = SKGError(ERR_FAIL,  i18nc("Error message", "Invalid name '%1' because of the name cannot contain '%2'" , iName, QString(OBJECTSEPARATOR)));
+    if (iName.contains(OBJECTSEPARATOR)) err = SKGError(ERR_FAIL,  i18nc("Error message", "Invalid name '%1' because of the name cannot contain '%2'" , iName, QString(OBJECTSEPARATOR)));
     else err = SKGNamedObject::setName(iName);
     return err;
 }
@@ -67,14 +67,14 @@ QString SKGCategoryObject::getWhereclauseId() const
 {
     //Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();
-    if(output.isEmpty()) {
-        if(!(getAttribute("t_name").isEmpty())) {
-            output = "t_name='" + SKGServices::stringToSqlString(getAttribute("t_name")) + '\'';
+    if (output.isEmpty()) {
+        if (!(getAttribute("t_name").isEmpty())) {
+            output = "t_name='" % SKGServices::stringToSqlString(getAttribute("t_name")) % '\'';
         }
-        QString r_category_id = getAttribute("r_category_id");
-        if(!output.isEmpty()) output += " AND ";
-        if(r_category_id.isEmpty()) output += "(r_category_id=0 OR r_category_id IS NULL OR r_category_id='')";
-        else output += "r_category_id=" + r_category_id;
+        QString rd_category_id = getAttribute("rd_category_id");
+        if (!output.isEmpty()) output += " AND ";
+        if (rd_category_id.isEmpty()) output += "(rd_category_id=0 OR rd_category_id IS NULL OR rd_category_id='')";
+        else output += "rd_category_id=" % rd_category_id;
     }
     return output;
 }
@@ -87,34 +87,36 @@ QString SKGCategoryObject::getFullName() const
 SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
         const QString& iFullPath,
         SKGCategoryObject& oCategory,
-        bool iSendPopupMessageOnCreation)
+        bool iSendPopupMessageOnCreation,
+        bool iRenameIfAlreadyExist)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGCategoryObject::createPathCategory", err);
 
     //Check if category is already existing
-    if(iFullPath.isEmpty()) {
+    if (iFullPath.isEmpty()) {
         oCategory = SKGCategoryObject(NULL, 0);
-    } else if(iDocument) {
-        iDocument->getObject("v_category", "t_fullname='" + SKGServices::stringToSqlString(iFullPath) + '\'', oCategory);
-        if(oCategory.getID() == 0) {
+    } else if (iDocument) {
+
+        if (!iRenameIfAlreadyExist && iDocument) iDocument->getObject("v_category", "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oCategory);
+        if (oCategory.getID() == 0) {
             //No, we have to create it
             //Search category separator
             int posSeparator = iFullPath.lastIndexOf(OBJECTSEPARATOR);
-            if(posSeparator == -1) {
-                //Not found, so it's only a single category
-                //Search if object already exist
-                //We don't catch the error because it's just to know
-                //if the object exists
-                iDocument->getObject("v_category", "t_name='" + SKGServices::stringToSqlString(iFullPath) +
-                                     "' AND (r_category_id=0 OR r_category_id IS NULL)", oCategory);
+            if (posSeparator == -1) {
+                oCategory = SKGCategoryObject(iDocument);
+                err = oCategory.setName(iFullPath);
 
-                if(oCategory.getID() == 0) {
-                    //Doesn't exist, we have to create it
-                    oCategory = SKGCategoryObject(iDocument);
-                    err = oCategory.setName(iFullPath);
-                    if(err.isSucceeded()) err = oCategory.save();
+                //Check if already existing
+                if (!err && iRenameIfAlreadyExist) {
+                    int index = 1;
+                    while (!err && oCategory.exist()) {
+                        index++;
+                        err = oCategory.setName(iFullPath % " (" % SKGServices::intToString(index) % ')');
+                    }
                 }
+
+                if (!err) err = oCategory.save();
             } else {
                 //Get first and second parts of the branch
                 QString first = iFullPath.mid(0, posSeparator);
@@ -124,19 +126,28 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
                 SKGCategoryObject FirstCategory;
                 err = SKGCategoryObject::createPathCategory(iDocument, first, FirstCategory);
 
-                if(err.isSucceeded()) {
+                if (!err) {
                     //Get second category
                     err = FirstCategory.addCategory(oCategory);
 
                     //Add second under first
-                    if(err.isSucceeded()) err = oCategory.setName(second);
+                    if (!err) err = oCategory.setName(second);
+
+                    //Check if already existing
+                    if (!err && iRenameIfAlreadyExist) {
+                        int index = 2;
+                        while (!err && oCategory.exist()) {
+                            err = oCategory.setName(second % " (" % SKGServices::intToString(index) % ')');
+                            ++index;
+                        }
+                    }
 
                     //save
-                    if(err.isSucceeded()) err = oCategory.save();
+                    if (!err) err = oCategory.save();
                 }
             }
 
-            if(err.isSucceeded() && iSendPopupMessageOnCreation && iDocument) {
+            if (!err && iSendPopupMessageOnCreation && iDocument) {
                 iDocument->sendMessage(i18nc("Information message", "Category '%1' has been created" , iFullPath), true);
             }
         }
@@ -149,10 +160,10 @@ SKGError SKGCategoryObject::addCategory(SKGCategoryObject& oCategory)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGCategoryObject::addCategory", err);
-    if(getID() == 0)  err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::addCategory")));
+    if (getID() == 0)  err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::addCategory")));
     else {
         oCategory = SKGCategoryObject(static_cast<SKGDocumentBank*>(getDocument()));
-        err = oCategory.setAttribute("r_category_id", SKGServices::intToString(getID()));
+        err = oCategory.setAttribute("rd_category_id", SKGServices::intToString(getID()));
     }
     return err;
 }
@@ -161,35 +172,35 @@ SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject& iCategory
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGCategoryObject::setParentCategory", err);
-    if(iCategory.getID() == 0) err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::setParentCategory")));
+    if (iCategory.getID() == 0) err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::setParentCategory")));
     else {
         //Check if it's a loop
         SKGCategoryObject current = iCategory;
         do {
-            if(current == *this) {
+            if (current == *this) {
                 err = SKGError(ERR_FAIL,  i18nc("Error message", "You cannot create a loop."));
             } else {
                 SKGCategoryObject parent;
                 current.getParentCategory(parent);
                 current = parent;
             }
-        } while(err.isSucceeded() && current.getID() != 0);
+        } while (!err && current.getID() != 0);
 
-        if(err.isSucceeded()) err = setAttribute("r_category_id", SKGServices::intToString(iCategory.getID()));
+        if (!err) err = setAttribute("rd_category_id", SKGServices::intToString(iCategory.getID()));
     }
     return err;
 }
 
 SKGError SKGCategoryObject::removeParentCategory()
 {
-    return setAttribute("r_category_id", "");
+    return setAttribute("rd_category_id", "");
 }
 
 SKGError SKGCategoryObject::getParentCategory(SKGCategoryObject& oCategory) const
 {
     SKGError err;
-    QString parent_id = getAttribute("r_category_id");
-    if(!parent_id.isEmpty()) err = getDocument()->getObject("v_category", "id=" + parent_id , oCategory);
+    QString parent_id = getAttribute("rd_category_id");
+    if (!parent_id.isEmpty()) err = getDocument()->getObject("v_category", "id=" % parent_id , oCategory);
     return err;
 }
 
@@ -198,8 +209,8 @@ SKGError SKGCategoryObject::getRootCategory(SKGCategoryObject& oCategory) const
     SKGError err;
     SKGCategoryObject parent;
     err = getParentCategory(parent);
-    if(err.isSucceeded()) {
-        if(!parent.exist()) {
+    if (!err) {
+        if (!parent.exist()) {
             //No parent
             oCategory = *this;
         } else {
@@ -214,7 +225,7 @@ SKGError SKGCategoryObject::getRootCategory(SKGCategoryObject& oCategory) const
 SKGError SKGCategoryObject::getCategories(SKGListSKGObjectBase& oCategoryList) const
 {
     return getDocument()->getObjects("v_category",
-                                     "r_category_id=" + SKGServices::intToString(getID()),
+                                     "rd_category_id=" % SKGServices::intToString(getID()),
                                      oCategoryList);
 }
 
@@ -227,25 +238,45 @@ double SKGCategoryObject::getCurrentAmount() const
 SKGError SKGCategoryObject::getSubOperations(SKGListSKGObjectBase& oSubOperations) const
 {
     SKGError err = getDocument()->getObjects("v_suboperation",
-                   "r_category_id=" + SKGServices::intToString(getID()) ,
+                   "r_category_id=" % SKGServices::intToString(getID()) ,
                    oSubOperations);
     return err;
 }
 
+SKGError SKGCategoryObject::bookmark(bool iBookmark)
+{
+    return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
+
+}
+
+bool SKGCategoryObject::isBookmarked() const
+{
+    return (getAttribute("t_bookmarked") == "Y" ? true : false);
+}
+
 SKGError SKGCategoryObject::merge(const SKGCategoryObject& iCategory)
 {
     SKGError err;
 
     SKGObjectBase::SKGListSKGObjectBase ops;
-    if(err.isSucceeded()) err = iCategory.getSubOperations(ops);
+    if (!err) err = iCategory.getSubOperations(ops);
     int nb = ops.count();
-    for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+    for (int i = 0; !err && i < nb; ++i) {
         SKGSubOperationObject op = ops.at(i);
         err = op.setCategory(*this);
-        if(err.isSucceeded()) err = op.save(true, false);
+        if (!err) err = op.save(true, false);
     }
 
-    if(err.isSucceeded()) err = iCategory.remove();
+    SKGObjectBase::SKGListSKGObjectBase cats;
+    if (!err) err = iCategory.getCategories(cats);
+    nb = cats.count();
+    for (int i = 0; !err && i < nb; ++i) {
+        SKGCategoryObject cat = cats.at(i);
+        err = cat.setParentCategory(*this);
+        if (!err) err = cat.save(true, false);
+    }
+
+    if (!err) err = iCategory.remove();
     return err;
 }
 
