@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -105,9 +105,10 @@ public Q_SLOTS:
     /**
         * Get formated percentage
         * @param iValue value
+        * @param iInvertColors to set positive value in red and negative values in green
         * @return formated value in red or black
         */
-    virtual QString formatPercentage(double iValue) const;
+    virtual QString formatPercentage(double iValue, bool iInvertColors = false) const;
 
     /**
      * Get Primary unit. WARNING: This value can be not uptodated in a transaction.
@@ -184,17 +185,16 @@ public Q_SLOTS:
     /**
      * Get budget report
      * @param iMonth the month
-     * @return the html report
+     * @return the report
      */
-    virtual QString getBudget(const QString& iMonth);
+    virtual QVariantList getBudget(const QString& iMonth);
 
     /**
      * Get 5 main category report
      * @param iMonth the month
-     * @param iChart to add chart
-     * @return the html report
+     * @return the report
      */
-    virtual QString get5MainCategories(const QString& iMonth, bool iChart = true);
+    virtual QVariantList get5MainCategories(const QString& iMonth);
 
     /**
      * Get 5 main variation of categories report
@@ -204,25 +204,14 @@ public Q_SLOTS:
      * @param oCategoryList to get the category for each variation
      * @return the list of variation string
      */
-    QStringList get5MainCategoriesVariationList(const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues = false, QStringList* oCategoryList = NULL);
+    virtual QStringList get5MainCategoriesVariationList(const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues = false, QStringList* oCategoryList = NULL);
 
     /**
-     * Get 5 main variation of categories report
-     * @param iMonth the month
-     * @param iPreviousMonth the previous month
-     * @param iOnlyIssues only "Expenses increased" and "Incomes decreased"
-     * @return the html report
+     * Enable/disable balances computation
      */
-    QString get5MainCategoriesVariation(const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues = false);
+    virtual void setComputeBalances(bool iEnabled);
 
 protected:
-    /**
-     * Get impacted tables if one object of @p iTable is modifier.
-     * @param iTable name of a table
-     * @return impacted tables
-     */
-    virtual QStringList getImpactedTable(const QString& iTable) const;
-
     /**
      * Migrate the current SKGDocument to the latest version of the data model.
      * WARNING: This method must be used in a transaction.
@@ -239,6 +228,7 @@ protected:
      *   @see SKGError
      */
     virtual SKGError computeBalances();
+
     /**
      * Compute the budgets categories links.
      * @return an object managing the error.
@@ -255,5 +245,10 @@ private:
     QString m_5mainVariations_inputs;
     QStringList m_5mainVariations_cache;
     QStringList m_5mainVariationsCat_cache;
+    bool m_computeBalances;
 };
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO(SKGDocumentBank, Q_MOVABLE_TYPE);
 #endif
