@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -28,14 +28,11 @@
 #include "skgerror.h"
 #include "skgbankmodeler_export.h"
 
-#ifdef SKG_ENABLE_OFX
-#include <libofx/libofx.h>
-#endif
-
 class SKGDocumentBank;
 class SKGAccountObject;
 class SKGUnitObject;
 class QDate;
+class SKGImportPlugin;
 
 /**
  *Manage import and export
@@ -49,60 +46,34 @@ class SKGBANKMODELER_EXPORT SKGImportExportManager : public QObject
     Q_ENUMS(ImportExportMode);
 
 public:
-    /**
-     * This enumerate defines dump modes
-     */
-    enum ImportExportMode {
-        AUTO,       /**< To export or inport in the right mode based on extension file */
-        CSV,        /**< To export or inport in CSV mode */
-        CSVUNIT,    /**< To inport in CSV mode values for a unit */
-        GNUCASH,    /**< To inport in GNUCASH file */
-        MMB,        /**< To inport in Money Manager Ex file */
-        GSB,        /**< To inport in GRISBI file */
-        XHB,        /**< To inport in HOMEBANK file */
-        SKG,        /**< To export or inport in SKROOGE file */
-        SQLITE,     /**< To export or inport in SQLITE file */
-        KMY,        /**< To export or inport in KMYMONEY file */
-        XML,        /**< To export in XML mode */
-        QIF,        /**< To export or inport in QIF mode */
-        OFX,        /**< To export or inport in OFX mode */
-        MT940       /**< To inport a MT940 file */
-    };
-
     /**
      * Constructor.
      * @param iDocument the document
      * @param iFileName the file name
-     * @param iMode the mode
      */
     explicit SKGImportExportManager(SKGDocumentBank* iDocument,
-                                    const QString& iFileName = "",
-                                    ImportExportMode iMode = SKGImportExportManager::AUTO);
+                                    const QString& iFileName = "");
 
     /**
      * Destructor
      */
     virtual ~SKGImportExportManager();
 
-    /**
-     * Get the import/export mode.
-     * @return the import/export mode
-     */
-    virtual ImportExportMode getMode();
-
     /**
      * Set the codec used for imports.
      * @param iCodec the codec name.
-     * @return an object managing the error.
-     *   @see SKGError
      */
-    virtual SKGError setCodec(const QString& iCodec);
+    virtual inline void setCodec(const QString& iCodec) {
+        m_codec = iCodec;
+    }
 
     /**
      * Get the codec used for imports.
      * @return code.
      */
-    virtual QString getCodec() const;
+    virtual inline QString getCodec() const {
+        return m_codec;
+    }
 
     /**
      * Set the default account for import in case of account is not detected in imported file.
@@ -136,97 +107,21 @@ public:
     virtual void setAutomaticApplyRules(bool iApply);
 
     /**
-     * Set the CSV mapping rule.
-     * A mapping rule is a list of regular expression allowing to automatically map each attribute:
-     * the operation object.
-     * List of supported attribute:
-     * date
-     * number
-     * mode
-     * payee
-     * comment
-     * status
-     * bookmarked
-     * account
-     * category
-     * amount
-     * quantity
-     * sign + debit
-     * unit
-     * This list is a list of operation attributes.
-     * @param iCSVMappingRules the mapping. NULL to build automatically the CSV mapping.
-     * @return an object managing the error.
-     *   @see SKGError
+     * Get parameters for Import
+     * @return the parameters
      */
-    virtual SKGError setCSVMappingRules(const QMap<QString, QString>& iCSVMappingRules);
+    virtual QMap<QString, QString> getImportParameters();
+    /**
+     * Set parameters for Import
+     * @param iParameters the parameters
+     */
+    virtual void setImportParameters(const QMap<QString, QString>& iParameters);
 
     /**
-     * Set the CSV mapping rule.
-     * A mapping rule is a list of regular expression allowing to automatically map each attribute:
-     * the operation object.
-     * List of supported attribute:
-     * date
-     * number
-     * mode
-     * payee
-     * comment
-     * status
-     * bookmarked
-     * account
-     * category
-     * amount
-     * quantity
-     * sign + debit
-     * unit
-     * This list is a list of operation attributes.
-     * @return the mapping rules.
+     * Get the mime type filter for import
+     * @return the mime type filter
      */
-    virtual  QMap<QString, QString> getCSVMappingRules();
-
-    /**
-     * Set the CSV mapping.
-     * A mapping is ordered list to described the mapping between the csv file and
-     * the operation object.
-     * List of supported key word:
-     * date
-     * number
-     * mode
-     * payee
-     * comment
-     * status
-     * bookmarked
-     * account
-     * category
-     * amount
-     * quantity
-     * sign
-     * unit
-     * This list is a list of operation attributes.
-     * @param iCSVMapping the mapping. NULL to build automatically the CSV mapping.
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError setCSVMapping(const QStringList* iCSVMapping = NULL);
-
-    /**
-     * Get the CSV mapping.
-     * @return the CSV mapping
-     */
-    virtual QStringList getCSVMapping() const;
-
-    /**
-     * Set the index of the header in the CSV file.
-     * @param iIndex the index. -1 to search automatically the index of the header.
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError setCSVHeaderIndex(int iIndex = -1);
-
-    /**
-     * Get the index of the header in the CSV file.
-     * @return the index
-     */
-    virtual int getCSVHeaderIndex();
+    static QString getImportMimeTypeFilter();
 
     /**
      * Import the file in the document
@@ -235,6 +130,12 @@ public:
      */
     virtual SKGError importFile();
 
+    /**
+     * Get the mime type filter for export
+     * @return the mime type filter
+     */
+    static QString getExportMimeTypeFilter();
+
     /**
      * Export the file in the document
      * @return an object managing the error.
@@ -269,14 +170,16 @@ public:
      * Get the document
      * @return the document.
      */
-    virtual SKGDocumentBank* getDocument();
-
+    virtual inline SKGDocumentBank* getDocument() {
+        return m_document;
+    }
     /**
      * Get file name
      * @return the file name.
      */
-    virtual QString getFileName();
-
+    virtual inline QString getFileName() {
+        return m_fileName;
+    }
     /**
      * Return the default account for import
      * @param oAccount the default account for import.
@@ -299,49 +202,26 @@ public:
     virtual SKGError getDefaultUnit(SKGUnitObject& oUnit, const QDate* iDate = NULL);
 
     /**
-     * To know if OFX i supported
-     * @return true or false.
+     * Finalize an import by changing state and applying rules
+     *   @see SKGError
      */
-    static bool isOFXSupported();
-
+    virtual SKGError finalizedImportedOperations();
 private:
     Q_DISABLE_COPY(SKGImportExportManager);
 
-    SKGError exportQIF();
-    SKGError exportCSV();
-    SKGError importQIF();
-    SKGError importCSV();
-#ifdef SKG_ENABLE_OFX
-    SKGError importOFX();
-#endif
-    SKGError importCSVUnit();
 
-#ifdef SKG_ENABLE_OFX
-    static int ofxAccountCallback(struct OfxAccountData data, void * pv);
-    static int ofxTransactionCallback(struct OfxTransactionData data, void * pv);
-    static int ofxStatementCallback(struct OfxStatementData data, void * pv);
-    static QList<OfxStatementData> m_ofxInitialBalance;
-    static SKGError getAccount(OfxAccountData* iAccountData, SKGDocumentBank* iDoc, SKGAccountObject& oAccount);
-#endif
-
-    static SKGError m_ofxError;
-
-    SKGError finalizedImportedOperations();
-
-    QStringList getCSVMappingFromLine(const QString& iLine);
+    SKGImportPlugin* getImportPlugin();
+    SKGImportPlugin* getExportPlugin();
 
     SKGDocumentBank* m_document;
-    ImportExportMode m_mode;
     QString m_fileName;
-    QStringList m_csvMapping;
-    QMap<QString, QString>  m_csvMapper;
-    QChar m_csvSeparator;
-    int m_csvHeaderIndex;
     SKGAccountObject* m_defaultAccount;
     SKGUnitObject* m_defaultUnit;
     QString m_codec;
     bool m_automaticValidationOfImportedOperation;
     bool m_automaticApplyRulesOfImportedOperation;
+    SKGImportPlugin* m_importPlugin;
+    SKGImportPlugin* m_exportPlugin;
 };
 
 #endif
