@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -39,14 +39,14 @@ SKGRuleObject::SKGRuleObject(const SKGRuleObject& iObject)
 
 SKGRuleObject::SKGRuleObject(const SKGObjectBase& iObject)
 {
-    if(iObject.getRealTable() == "rule") {
+    if (iObject.getRealTable() == "rule") {
         copyFrom(iObject);
     } else {
         *this = SKGObjectBase(iObject.getDocument(), "v_rule", iObject.getID());
     }
 }
 
-const SKGRuleObject& SKGRuleObject::operator= (const SKGObjectBase & iObject)
+const SKGRuleObject& SKGRuleObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -73,7 +73,7 @@ SKGError SKGRuleObject::save(bool iInsertOrUpdate, bool iReloadAfterSave)
     SKGError err = SKGObjectBase::save(iInsertOrUpdate, iReloadAfterSave);
 
     //Raise alarm
-    if(err.isSucceeded() && getActionType() == ALARM) err = execute();
+    if (!err && getActionType() == ALARM) err = execute();
 
     return err;
 }
@@ -136,13 +136,13 @@ SKGError SKGRuleObject::setOrder(double iOrder)
 {
     SKGError err;
     double order = iOrder;
-    if(order == -1) {
+    if (order == -1) {
         order = 1;
         SKGStringListList result;
         err = getDocument()->executeSelectSqliteOrder("SELECT max(f_sortorder) from rule", result);
-        if(err.isSucceeded() && result.count() == 2) order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
+        if (!err && result.count() == 2) order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
     }
-    if(err.isSucceeded()) err = setAttribute("f_sortorder", SKGServices::doubleToString(order));
+    if (!err) err = setAttribute("f_sortorder", SKGServices::doubleToString(order));
     return err;
 }
 
@@ -150,12 +150,12 @@ QString SKGRuleObject::getSelectSqlOrder(const QString& iAdditionalCondition) co
 {
     QString wc = iAdditionalCondition;
     QString wc2 = SKGRuleObject::getDescriptionFromXML((SKGDocument*) getDocument(), getXMLSearchDefinition(), true, SEARCH);
-    if(!wc2.isEmpty()) {
-        if(wc.isEmpty()) wc = wc2;
-        else wc = '(' + wc + ") AND (" + wc2 + ')';
+    if (!wc2.isEmpty()) {
+        if (wc.isEmpty()) wc = wc2;
+        else wc = '(' % wc % ") AND (" % wc2 % ')';
     }
-    if(wc.isEmpty()) wc = "1=1";
-    wc = "d_date!='0000-00-00' AND (" + wc + ')';
+    if (wc.isEmpty()) wc = "1=1";
+    wc = "d_date!='0000-00-00' AND (" % wc % ')';
     return wc;
 }
 
@@ -163,21 +163,21 @@ SKGRuleObject::SKGAlarmInfo SKGRuleObject::getAlarmInfo() const
 {
     SKGTRACEIN(10, "SKGRuleObject::getAlarmInfo");
     SKGRuleObject::SKGAlarmInfo alarm;
-    if(getActionType() == SKGRuleObject::ALARM) {
+    if (getActionType() == SKGRuleObject::ALARM) {
         //Alarm mode
         QString wc = getSelectSqlOrder();
-        if(wc.isEmpty()) wc = "1=1";
+        if (wc.isEmpty()) wc = "1=1";
 
         SKGDocument* doc = (SKGDocument*) getDocument();
 
         QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, ALARM, false);
-        if(list.count()) {
+        if (list.count()) {
             QString sql = list.at(0);
             sql.replace("#WC#", wc);
 
             SKGStringListList result;
             doc->executeSelectSqliteOrder(sql, result);
-            if(result.count() == 2) {
+            if (result.count() == 2) {
                 QStringList r = result.at(1);
                 alarm.Message = r.at(3);
                 alarm.Amount = SKGServices::stringToDouble(r.at(1));
@@ -191,61 +191,67 @@ SKGRuleObject::SKGAlarmInfo SKGRuleObject::getAlarmInfo() const
 SKGError SKGRuleObject::execute(ProcessMode iMode)
 {
     SKGError err;
-    if(getActionType() == SKGRuleObject::UPDATE) {
+    if (getActionType() == SKGRuleObject::UPDATE) {
         //Update mode
         QString addSql;
-        if(iMode == IMPORTED) addSql = "t_imported!='N'";
-        else if(iMode == IMPORTEDNOTVALIDATE) addSql = "t_imported='P'";
-        else if(iMode == IMPORTING) addSql = "t_imported='T'";
+        if (iMode == IMPORTED) addSql = "t_imported!='N'";
+        else if (iMode == IMPORTEDNOTVALIDATE) addSql = "t_imported='P'";
+        else if (iMode == IMPORTING) addSql = "t_imported='T'";
 
         QString wc = getSelectSqlOrder(addSql);
-        if(wc.isEmpty()) wc = "1=1";
+        if (wc.isEmpty()) wc = "1=1";
 
         SKGDocument* doc = (SKGDocument*) getDocument();
-        if(doc) {
+        if (doc) {
             QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, UPDATE, true);  //SQL + SET clause
             int nb = list.count();
-            err = doc->beginTransaction("#INTERNAL#", nb);
-            for(int i = 0; err.isSucceeded() && i < nb; ++i) {
-                QString sql = list.at(i);
-                sql.replace("#WC#", wc);
-                err = doc->executeSqliteOrder(sql);
-                if(err.isSucceeded()) err = doc->stepForward(i + 1);
-            }
-
-            if(err.isSucceeded()) {
-                SKGStringListList result;
-                err = doc->executeSelectSqliteOrder("SELECT changes()", result);
-                if(err.isSucceeded() && result.count() == 2) {
-                    int nb = SKGServices::stringToInt(result.at(1).at(0));
-                    if(nb) doc->sendMessage(i18np("1 operation modified by %2", "%1 operations modified by %2", nb, getAttribute("i_ORDER")));
+            err = doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Apply rule"), nb);
+            if (!err) {
+                //All sql orders must be executed to be sure than i_tmp is reset
+                SKGError err2;
+                for (int i = 0; i < nb; ++i) {
+                    QString sql = list.at(i);
+                    sql.replace("#WC#", wc);
+                    err2 = doc->executeSqliteOrder(sql);
+                    if (!err2) err2 = doc->stepForward(i + 1);
+                    if (err2 && !err) err = err2;
                 }
             }
 
-            if(err.isSucceeded()) err = doc->endTransaction(true);
+            if (!err) {
+                SKGStringListList result;
+                err = doc->executeSelectSqliteOrder("SELECT changes()", result);
+                if (!err && result.count() == 2) {
+                    int nb = SKGServices::stringToInt(result.at(1).at(0));
+                    if (nb) doc->sendMessage(i18np("1 operation modified by %2", "%1 operations modified by %2", nb, getAttribute("i_ORDER")));
+                }
+            }
+
+            if (!err) err = doc->endTransaction(true);
             else doc->endTransaction(false);
         }
-    } else if(getActionType() == SKGRuleObject::ALARM) {
+    } else if (getActionType() == SKGRuleObject::ALARM) {
         //Alarm mode
         QString wc = getSelectSqlOrder();
-        if(wc.isEmpty()) wc = "1=1";
+        if (wc.isEmpty()) wc = "1=1";
 
         SKGDocument* doc = (SKGDocument*) getDocument();
-        if(doc) {
+        if (doc) {
             QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, ALARM, false);
-            if(list.count()) {
+            if (list.count()) {
                 QString sql = list.at(0);
                 sql.replace("#WC#", wc);
 
                 SKGStringListList result;
                 err = doc->executeSelectSqliteOrder(sql, result);
-                if(err.isSucceeded() && result.count() == 2) {
+                if (!err && result.count() == 2) {
                     //Is alarm raised ?
-                    if(result.at(1).at(0) == "1") doc->sendMessage(result.at(1).at(3));
+                    if (result.at(1).at(0) == "1") doc->sendMessage(result.at(1).at(3));
                 }
             }
         }
     }
+    if (err) err.addError(ERR_FAIL, i18nc("Error message", "Rule %1 failed", getAttribute("i_ORDER")));
     return err;
 }
 
@@ -257,86 +263,86 @@ double SKGRuleObject::getOrder() const
 QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QString& iParam1, const QString& iParam2, const QString& iAtt2)
 {
     QString output = iOperator;
-    if(output == "#ATT# LIKE '%#V1S#%'")
+    if (output == "#ATT# LIKE '%#V1S#%'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "contains '#V1S#'").replace("#V1S#", iParam1);
-    else if(output == "#ATT# LIKE '#V1S#%'")
+    else if (output == "#ATT# LIKE '#V1S#%'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "starts with '#V1S#'").replace("#V1S#", iParam1);
-    else if(output == "#ATT# LIKE '%#V1S#'")
+    else if (output == "#ATT# LIKE '%#V1S#'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "ends with '#V1S#'").replace("#V1S#", iParam1);
-    else if(output == "#ATT#=''")
+    else if (output == "#ATT#=''")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is empty");
-    else if(output == "#ATT#!=''")
+    else if (output == "#ATT#!=''")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not empty");
 
-    else if(output == "#ATT#=#V1#")
+    else if (output == "#ATT#=#V1#")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#V1#").replace("#V1#", iParam1);
-    else if(output == "#ATT#!=#V1#")
+    else if (output == "#ATT#!=#V1#")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "!=#V1#").replace("#V1#", iParam1);
-    else if(output == "#ATT#>#V1#")
+    else if (output == "#ATT#>#V1#")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">#V1#").replace("#V1#", iParam1);
-    else if(output == "#ATT#<#V1#")
+    else if (output == "#ATT#<#V1#")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<#V1#").replace("#V1#", iParam1);
-    else if(output == "#ATT#>=#V1#")
+    else if (output == "#ATT#>=#V1#")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">=#V1#").replace("#V1#", iParam1);
-    else if(output == "#ATT#<=#V1#")
+    else if (output == "#ATT#<=#V1#")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<=#V1#").replace("#V1#", iParam1);
 
-    else if(output == "#ATT#='#V1S#'")
+    else if (output == "#ATT#='#V1S#'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "='#V1S#'").replace("#V1S#", iParam1);
-    else if(output == "#ATT#!='#V1S#'")
+    else if (output == "#ATT#!='#V1S#'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "!='#V1S#'").replace("#V1S#", iParam1);
-    else if(output == "#ATT#>'#V1S#'")
+    else if (output == "#ATT#>'#V1S#'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">'#V1S#'").replace("#V1S#", iParam1);
-    else if(output == "#ATT#<'#V1S#'")
+    else if (output == "#ATT#<'#V1S#'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<'#V1S#'").replace("#V1S#", iParam1);
-    else if(output == "#ATT#>='#V1S#'")
+    else if (output == "#ATT#>='#V1S#'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">='#V1S#'").replace("#V1S#", iParam1);
-    else if(output == "#ATT#<='#V1S#'")
+    else if (output == "#ATT#<='#V1S#'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<='#V1S#'").replace("#V1S#", iParam1);
 
-    else if(output == "#ATT#>=#V1# AND #ATT#<=#V2#")
+    else if (output == "#ATT#>=#V1# AND #ATT#<=#V2#")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is between #V1# and #V2#").replace("#V1#", iParam1).replace("#V2#", iParam2);
-    else if(output == "#ATT#>='#V1S#' AND #ATT#<='#V2S#'")
+    else if (output == "#ATT#>='#V1S#' AND #ATT#<='#V2S#'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is between '#V1S#' and '#V2S#'").replace("#V1S#", iParam1).replace("#V2S#", iParam2);
-    else if(output == "#ATT#=lower(#ATT#)")
+    else if (output == "#ATT#=lower(#ATT#)")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to lower");
-    else if(output == "#ATT#=upper(#ATT#)")
+    else if (output == "#ATT#=upper(#ATT#)")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to upper");
-    else if(output == "#ATT#!=lower(#ATT#)")
+    else if (output == "#ATT#!=lower(#ATT#)")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not lower");
-    else if(output == "#ATT#!=upper(#ATT#)")
+    else if (output == "#ATT#!=upper(#ATT#)")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not upper");
 
-    else if(output == "#ATT#=replace(#ATT2#,'#V1S#','#V2S#')")
+    else if (output == "#ATT#=replace(#ATT2#,'#V1S#','#V2S#')")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2# with '#V1S#' replaced by '#V2S#'").replace("#V1S#", iParam1).replace("#V2S#", iParam2).replace("#ATT2#", iAtt2);
-    else if(output == "#ATT#=substr(#ATT2#,'#V1#','#V2#')")
+    else if (output == "#ATT#=substr(#ATT2#,'#V1#','#V2#')")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=substring of #ATT2# from #V1# to #V2#").replace("#V1#", iParam1).replace("#V2#", iParam2).replace("#ATT2#", iAtt2);
-    else if(output == "#ATT#=#ATT2#")
+    else if (output == "#ATT#=#ATT2#")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2#").replace("#ATT2#", iAtt2);
 
-    else if(output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))")
+    else if (output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current month");
-    else if(output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','start of month','-1 month'))")
+    else if (output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','start of month','-1 month'))")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in previous month");
-    else if(output == "STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now'))")
+    else if (output == "STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now'))")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current year");
-    else if(output == "STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now','start of month','-1 year'))")
+    else if (output == "STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now','start of month','-1 year'))")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in previous year");
-    else if(output == "#ATT#>date('now','-30 day') AND #ATT#<=date('now')")
+    else if (output == "#ATT#>date('now','-30 day') AND #ATT#<=date('now')")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 30 days");
-    else if(output == "#ATT#>date('now','-3 month') AND #ATT#<=date('now')")
+    else if (output == "#ATT#>date('now','-3 month') AND #ATT#<=date('now')")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 3 months");
-    else if(output == "#ATT#>date('now','-6 month') AND #ATT#<=date('now')")
+    else if (output == "#ATT#>date('now','-6 month') AND #ATT#<=date('now')")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 6 months");
-    else if(output == "#ATT#>date('now','-12 month') AND #ATT#<=date('now')")
+    else if (output == "#ATT#>date('now','-12 month') AND #ATT#<=date('now')")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 12 months");
-    else if(output == "#ATT#>date('now','-2 year') AND #ATT#<=date('now')")
+    else if (output == "#ATT#>date('now','-2 year') AND #ATT#<=date('now')")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 2 years");
-    else if(output == "#ATT#>date('now','-3 year') AND #ATT#<=date('now')")
+    else if (output == "#ATT#>date('now','-3 year') AND #ATT#<=date('now')")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 3 years");
-    else if(output == "#ATT#>date('now','-5 year') AND #ATT#<=date('now')")
+    else if (output == "#ATT#>date('now','-5 year') AND #ATT#<=date('now')")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 5 years");
-    else if(output == "ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'")
+    else if (output == "ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "If total(#ATT#)#OP##V1# then send '#V2S#'").replace("#V1#", iParam1).replace("#V2S#", iParam2).replace("#OP#", iAtt2);
 
     return output;
@@ -345,26 +351,26 @@ QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QSt
 QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttributeType, SKGRuleObject::ActionType iType)
 {
     QStringList output;
-    if(iType == UPDATE) {
+    if (iType == UPDATE) {
         //Mode update
-        if(iAttributeType == SKGServices::TEXT) {
+        if (iAttributeType == SKGServices::TEXT) {
             output.push_back("#ATT#='#V1S#'");
             output.push_back("#ATT#=lower(#ATT#)");
             output.push_back("#ATT#=upper(#ATT#)");
             output.push_back("#ATT#=replace(#ATT2#,'#V1S#','#V2S#')");
-        } else if(iAttributeType == SKGServices::INTEGER || iAttributeType == SKGServices::FLOAT) {
+        } else if (iAttributeType == SKGServices::INTEGER || iAttributeType == SKGServices::FLOAT) {
             output.push_back("#ATT#=#V1#");
-        } else if(iAttributeType == SKGServices::DATE || iAttributeType == SKGServices::BOOL || iAttributeType == SKGServices::TRISTATE) {
+        } else if (iAttributeType == SKGServices::DATE || iAttributeType == SKGServices::BOOL || iAttributeType == SKGServices::TRISTATE) {
             output.push_back("#ATT#='#V1S#'");
         }
 
-        if(iAttributeType != SKGServices::BOOL && iAttributeType != SKGServices::TRISTATE) {
+        if (iAttributeType != SKGServices::BOOL && iAttributeType != SKGServices::TRISTATE) {
             output.push_back("#ATT#=substr(#ATT2#,'#V1#','#V2#')");
             output.push_back("#ATT#=#ATT2#");
         }
-    } else if(iType == SEARCH) {
+    } else if (iType == SEARCH) {
         //Mode query
-        if(iAttributeType == SKGServices::TEXT) {
+        if (iAttributeType == SKGServices::TEXT) {
             output.push_back("#ATT# LIKE '%#V1S#%'");
             output.push_back("#ATT# LIKE '#V1S#%'");
             output.push_back("#ATT# LIKE '%#V1S#'");
@@ -374,7 +380,7 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
             output.push_back("#ATT#!=upper(#ATT#)");
         }
 
-        if(iAttributeType == SKGServices::INTEGER || iAttributeType == SKGServices::FLOAT) {
+        if (iAttributeType == SKGServices::INTEGER || iAttributeType == SKGServices::FLOAT) {
             output.push_back("#ATT#=#V1#");
             output.push_back("#ATT#!=#V1#");
             output.push_back("#ATT#>#V1#");
@@ -384,15 +390,15 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
             output.push_back("#ATT#>=#V1# AND #ATT#<=#V2#");
         }
 
-        if(iAttributeType == SKGServices::BOOL || iAttributeType == SKGServices::TRISTATE || iAttributeType == SKGServices::TEXT || iAttributeType == SKGServices::DATE) {
+        if (iAttributeType == SKGServices::BOOL || iAttributeType == SKGServices::TRISTATE || iAttributeType == SKGServices::TEXT || iAttributeType == SKGServices::DATE) {
             output.push_back("#ATT#='#V1S#'");
         }
 
-        if(iAttributeType == SKGServices::TRISTATE || iAttributeType == SKGServices::TEXT || iAttributeType == SKGServices::DATE) {
+        if (iAttributeType == SKGServices::TRISTATE || iAttributeType == SKGServices::TEXT || iAttributeType == SKGServices::DATE) {
             output.push_back("#ATT#!='#V1S#'");
         }
 
-        if(iAttributeType == SKGServices::TEXT || iAttributeType == SKGServices::DATE) {
+        if (iAttributeType == SKGServices::TEXT || iAttributeType == SKGServices::DATE) {
             output.push_back("#ATT#>'#V1S#'");
             output.push_back("#ATT#<'#V1S#'");
             output.push_back("#ATT#>='#V1S#'");
@@ -400,7 +406,7 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
             output.push_back("#ATT#>='#V1S#' AND #ATT#<='#V2S#'");
         }
 
-        if(iAttributeType == SKGServices::DATE) {
+        if (iAttributeType == SKGServices::DATE) {
             output.push_back("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))");
             output.push_back("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','start of month','-1 month'))");
             output.push_back("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now'))");
@@ -413,7 +419,7 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
             output.push_back("#ATT#>date('now','-3 year') AND #ATT#<=date('now')");
             output.push_back("#ATT#>date('now','-5 year') AND #ATT#<=date('now')");
         }
-    } else if(iType == ALARM) {
+    } else if (iType == ALARM) {
         output.push_back("ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'");
     }
     return output;
@@ -422,7 +428,7 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
 QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXML, bool iSQL, SKGRuleObject::ActionType iType, bool iFullUpdate)
 {
     QStringList output;
-    if(iFullUpdate) {
+    if (iFullUpdate) {
         //Add markers
         output.push_back("UPDATE suboperation set i_tmp=1 WHERE id IN (SELECT i_SUBOPID FROM v_operation_prop WHERE #WC#)");
         output.push_back("UPDATE operation set i_tmp=1 WHERE id IN (SELECT id FROM v_operation_prop WHERE #WC#)");
@@ -434,26 +440,26 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
     QDomElement root = doc.documentElement();
 
     QDomNode l = root.firstChild();
-    while(!l.isNull()) {
+    while (!l.isNull()) {
         QDomElement elementl = l.toElement();
-        if(!elementl.isNull()) {
+        if (!elementl.isNull()) {
             QString lineDescription;
 
             QDomNode n = elementl.firstChild();
             bool parenthesisNeeded = false;
-            while(!n.isNull()) {
+            while (!n.isNull()) {
                 QDomElement element = n.toElement();
-                if(!element.isNull()) {
+                if (!element.isNull()) {
                     //Build element description
                     QString elementDescription;
                     QString attribute = SKGServices::stringToSqlString(element.attribute("attribute"));
                     QString propName;
-                    if(iSQL) {
-                        if(attribute.startsWith(QLatin1String("p_"))) {
+                    if (iSQL) {
+                        if (attribute.startsWith(QLatin1String("p_"))) {
                             //Case property
                             propName = attribute.right(attribute.length() - 2);
-                            if(iType == SEARCH) {
-                                attribute = "i_PROPPNAME='" + SKGServices::stringToSqlString(propName) + "' AND i_PROPVALUE";
+                            if (iType == SEARCH) {
+                                attribute = "i_PROPPNAME='" % SKGServices::stringToSqlString(propName) % "' AND i_PROPVALUE";
                             } else {
                                 attribute = "t_value";
                             }
@@ -468,16 +474,16 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
 
                         elementDescription += part;
                     } else {
-                        attribute = "operation." + attribute;
-                        if(iDocument) attribute = iDocument->getDisplay(attribute);
+                        attribute = "operation." % attribute;
+                        if (iDocument) attribute = iDocument->getDisplay(attribute);
 
-                        if(iType != ALARM) {
+                        if (iType != ALARM) {
                             elementDescription = attribute;
                             elementDescription += ' ';
                         }
 
                         QString tmp = SKGServices::stringToSqlString(element.attribute("att2s"));
-                        if(tmp.isEmpty()) tmp = SKGServices::stringToSqlString(element.attribute("operator2"));
+                        if (tmp.isEmpty()) tmp = SKGServices::stringToSqlString(element.attribute("operator2"));
                         QString part = SKGRuleObject::getDisplayForOperator(element.attribute("operator"),
                                        SKGServices::stringToSqlString(element.attribute("value")),
                                        SKGServices::stringToSqlString(element.attribute("value2")),
@@ -490,49 +496,49 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
 
                     //Att2
                     QString attribute2 = SKGServices::stringToSqlString(element.attribute("att2"));
-                    if(iSQL) {
-                        if(attribute2.startsWith(QLatin1String("p_"))) {
+                    if (iSQL) {
+                        if (attribute2.startsWith(QLatin1String("p_"))) {
                             QString propertyName = attribute2.right(attribute2.length() - 2);
-                            attribute2 = "ifnull((SELECT v_operation_prop.i_PROPVALUE FROM v_operation_prop WHERE v_operation_prop.id=operation.id AND v_operation_prop.i_PROPPNAME='" + SKGServices::stringToSqlString(propertyName) + "'),'')";
+                            attribute2 = "IFNULL((SELECT v_operation_prop.i_PROPVALUE FROM v_operation_prop WHERE v_operation_prop.id=operation.id AND v_operation_prop.i_PROPPNAME='" % SKGServices::stringToSqlString(propertyName) % "'),'')";
                         } else {
-                            attribute2 = "(SELECT " + attribute2 + " FROM v_operation_consolidated WHERE v_operation_consolidated.id=operation.id)";
+                            attribute2 = "(SELECT " % attribute2 % " FROM v_operation_consolidated WHERE v_operation_consolidated.id=operation.id)";
                         }
                     }
                     elementDescription = elementDescription.replace("#ATT2#", attribute2);
 
                     //Add it to line description
-                    if(iSQL) {
-                        if(iType == UPDATE) {
-                            if(!iFullUpdate) {
+                    if (iSQL) {
+                        if (iType == UPDATE) {
+                            if (!iFullUpdate) {
                                 output.push_back(elementDescription);
                             } else {
                                 QString sqlOrder;
-                                if(attribute == "t_REALCATEGORY") {
+                                if (attribute == "t_REALCATEGORY") {
                                     elementDescription.replace(attribute, "t_fullname");
-                                    output.push_back("UPDATE suboperation set r_category_id=(SELECT id FROM category WHERE " + elementDescription + ") WHERE i_tmp=1");
-                                } else if(attribute == "t_ACCOUNT") {
+                                    output.push_back("UPDATE suboperation set r_category_id=IFNULL((SELECT id FROM category WHERE " % elementDescription % "),0) WHERE i_tmp=1");
+                                } else if (attribute == "t_ACCOUNT") {
                                     elementDescription.replace(attribute, "t_name");
-                                    output.push_back("UPDATE operation set rd_account_id=(SELECT id FROM account WHERE " + elementDescription + ") WHERE i_tmp=1");
-                                } else if(attribute == "t_PAYEE") {
+                                    output.push_back("UPDATE operation set rd_account_id=IFNULL((SELECT id FROM account WHERE " % elementDescription % "),0) WHERE i_tmp=1");
+                                } else if (attribute == "t_PAYEE") {
                                     elementDescription.replace(attribute, "t_name");
-                                    output.push_back("UPDATE operation set r_payee_id=(SELECT id FROM payee WHERE " + elementDescription + ") WHERE i_tmp=1");
-                                } else if(attribute == "t_REALREFUND") {
+                                    output.push_back("UPDATE operation set r_payee_id=IFNULL((SELECT id FROM payee WHERE " % elementDescription % "),0) WHERE i_tmp=1");
+                                } else if (attribute == "t_REALREFUND") {
                                     elementDescription.replace(attribute, "t_name");
-                                    output.push_back("UPDATE suboperation set r_refund_id=(SELECT id FROM refund WHERE " + elementDescription + ") WHERE i_tmp=1");
-                                } else if(element.attribute("attribute").startsWith(QLatin1String("p_"))) {
-                                    output.push_back("INSERT OR IGNORE INTO parameters (t_uuid_parent, t_name, i_tmp) SELECT o.id||'-operation', '" + SKGServices::stringToSqlString(propName) + "', 1 FROM operation o WHERE o.i_tmp=1");
-                                    output.push_back("UPDATE parameters set " + elementDescription + " WHERE i_tmp=1 AND t_name='" + SKGServices::stringToSqlString(propName) + "' AND NOT(" + elementDescription + ')');
-                                    output.push_back("DELETE FROM parameters WHERE i_tmp=1 AND t_name='" + SKGServices::stringToSqlString(propName) + "' AND t_value=''");
+                                    output.push_back("UPDATE suboperation set r_refund_id=IFNULL((SELECT id FROM refund WHERE " % elementDescription % "),0) WHERE i_tmp=1");
+                                } else if (element.attribute("attribute").startsWith(QLatin1String("p_"))) {
+                                    output.push_back("INSERT OR IGNORE INTO parameters (t_uuid_parent, t_name, i_tmp) SELECT o.id||'-operation', '" % SKGServices::stringToSqlString(propName) % "', 1 FROM operation o WHERE o.i_tmp=1");
+                                    output.push_back("UPDATE parameters set " % elementDescription % " WHERE i_tmp=1 AND t_name='" % SKGServices::stringToSqlString(propName) % "' AND NOT(" % elementDescription % ')');
+                                    output.push_back("DELETE FROM parameters WHERE i_tmp=1 AND t_name='" % SKGServices::stringToSqlString(propName) % "' AND t_value=''");
                                 } else {
-                                    output.push_back("UPDATE operation set " + elementDescription + " WHERE i_tmp=1 AND NOT(" + elementDescription + ')');
+                                    output.push_back("UPDATE operation set " % elementDescription % " WHERE i_tmp=1 AND NOT(" % elementDescription % ')');
                                 }
                             }
-                        } else if(iType == ALARM) {
-                            output.push_back("SELECT " + elementDescription + " FROM v_operation_consolidated WHERE #WC#");
+                        } else if (iType == ALARM) {
+                            output.push_back("SELECT " % elementDescription % " FROM v_operation_consolidated WHERE #WC#");
                         }
                     }
 
-                    if(!lineDescription.isEmpty()) {
+                    if (!lineDescription.isEmpty()) {
                         lineDescription += (iType == UPDATE ? " , " : (iSQL ? " AND " : i18nc("logical operator in a search query", " and ")));
                         parenthesisNeeded = true;
                     }
@@ -541,15 +547,15 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                 n = n.nextSibling();
             }
 
-            if(!(iType != SEARCH && iSQL) && !lineDescription.isEmpty()) {
-                if(iType == SEARCH && parenthesisNeeded) lineDescription = '(' + lineDescription + ')';
+            if (!(iType != SEARCH && iSQL) && !lineDescription.isEmpty()) {
+                if (iType == SEARCH && parenthesisNeeded) lineDescription = '(' % lineDescription % ')';
                 output.push_back(lineDescription);
             }
         }
         l = l.nextSibling();
     }
 
-    if(iFullUpdate) {
+    if (iFullUpdate) {
         //Remove markers
         output.push_back("UPDATE suboperation set i_tmp=0 WHERE i_tmp=1");
         output.push_back("UPDATE operation set i_tmp=0 WHERE i_tmp=1");
@@ -564,9 +570,9 @@ QString SKGRuleObject::getDescriptionFromXML(SKGDocument* iDocument, const QStri
 
     QStringList list = getFromXML(iDocument, iXML, iSQL, iType);
     int nb = list.count();
-    for(int i = 0; i < nb; ++i) {
+    for (int i = 0; i < nb; ++i) {
         output.append(list[i]);
-        if(i < nb - 1) output.append(iType != SEARCH ? " , " : (iSQL ? " OR " : i18nc("logical operator in a search query", " or ")));
+        if (i < nb - 1) output.append(iType != SEARCH ? " , " : (iSQL ? " OR " : i18nc("logical operator in a search query", " or ")));
     }
     return output;
 }
