@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,16 +21,18 @@
  */
 #include "skgfilteredtableview.h"
 #include "skgsortfilterproxymodel.h"
+#include "skgmainpanel.h"
 
 #include <QDomDocument>
 #include <klineedit.h>
 
-SKGFilteredTableView::SKGFilteredTableView(QWidget *parent)
-    : QWidget(parent), m_objectModel(NULL)
+SKGFilteredTableView::SKGFilteredTableView(QWidget* parent)
+    : QWidget(parent), m_objectModel(NULL), m_refreshNeeded(true)
 {
     ui.setupUi(this);
 
     connect(ui.kShow, SIGNAL(stateChanged()), this, SLOT(onFilterChanged()), Qt::QueuedConnection);
+    if (SKGMainPanel::getMainPanel()) connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
 }
 
 SKGFilteredTableView::~SKGFilteredTableView()
@@ -64,7 +66,7 @@ void SKGFilteredTableView::setState(const QString& iState)
     ui.kShow->setState(show);
     ui.kFilterEdit->setText(filter);
 
-    if(m_objectModel) {
+    if (m_objectModel) {
         bool previous = m_objectModel->blockRefresh(true);
         onFilterChanged();
         m_objectModel->blockRefresh(previous);
@@ -89,20 +91,31 @@ void SKGFilteredTableView::onFilterChanged()
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
     //Update model
-    if(m_objectModel) {
-        m_objectModel->setFilter(ui.kShow->isEnabled() ? ui.kShow->getWhereClause() : "");
-        ui.kView->setState(ui.kView->getState());
+    if (m_objectModel && m_objectModel->setFilter(ui.kShow->isEnabled() ? ui.kShow->getWhereClause() : "")) {
+        m_objectModel->dataModified();
     }
 
     QApplication::restoreOverrideCursor();
 }
 
+void SKGFilteredTableView::pageChanged()
+{
+    if (m_refreshNeeded) dataModified("", 0);
+}
+
 void SKGFilteredTableView::dataModified(const QString& iTableName, int iIdTransaction)
 {
     Q_UNUSED(iIdTransaction);
 
-    if((m_objectModel && iTableName == m_objectModel->getRealTable()) || iTableName.isEmpty()) {
-        if(getView()->isAutoResized()) getView()->resizeColumnsToContentsDelayed();
+    if ((m_objectModel && iTableName == m_objectModel->getTable()) || iTableName.isEmpty()) {
+        SKGTabPage* page = SKGTabPage::parentTabPage(this);
+        if (page != NULL && page != SKGMainPanel::getMainPanel()->currentPage()) {
+            m_refreshNeeded = true;
+            return;
+        }
+        m_refreshNeeded = false;
+
+        if (getView()->isAutoResized()) getView()->resizeColumnsToContentsDelayed();
 
         getView()->onSelectionChanged();
     }
@@ -110,7 +123,7 @@ void SKGFilteredTableView::dataModified(const QString& iTableName, int iIdTransa
 void SKGFilteredTableView::setModel(SKGObjectModelBase* iModel)
 {
     m_objectModel = iModel;
-    if(m_objectModel) {
+    if (m_objectModel) {
         SKGSortFilterProxyModel* modelProxy = new SKGSortFilterProxyModel(this);
         modelProxy->setSourceModel(m_objectModel);
         modelProxy->setSortRole(Qt::UserRole);
@@ -124,7 +137,7 @@ void SKGFilteredTableView::setModel(SKGObjectModelBase* iModel)
 
         connect(m_objectModel, SIGNAL(beforeReset()), ui.kView, SLOT(saveSelection()));
         connect(m_objectModel, SIGNAL(afterReset()), ui.kView, SLOT(resetSelection()));
-        connect(m_objectModel->getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)), Qt::QueuedConnection);
+        connect(m_objectModel->getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     }
     dataModified("", 0);
 }
