@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,6 +26,7 @@
 
 #include "skgdocument.h"
 #include "skgtabpage.h"
+#include "skgadvice.h"
 #include "skgerror.h"
 #include "skgbasegui_export.h"
 class SKGMainPanel;
@@ -39,22 +40,11 @@ class SKGBASEGUI_EXPORT SKGInterfacePlugin : public KParts::Plugin
 {
     Q_OBJECT ;
 public:
-    /**
-     * Describe a modification of an object
-     */
-    struct SKGAdvice {
-        QString uuid;               /**< The uuid of the advice */
-        int priority;               /**< The priority of the advice (0=low, 10=high) */
-        QString shortMessage;           /**< The short message of the advice */
-        QString longMessage;            /**< The long message of the advice */
-        QStringList autoCorrection;     /**< The message in case of this advice could be auto cleaned. One line per possible solutions */
-    } ;
-
     /**
      * Default constructor
      * @param parent the parent of the plugin
      */
-    SKGInterfacePlugin(QObject * parent = 0);
+    SKGInterfacePlugin(QObject* parent = 0);
 
     /**
      * Default destructor
@@ -86,8 +76,8 @@ public:
     virtual void refresh();
 
     /**
-     * The context widget of the plugin.
-     * @return The context widget of the plugin
+     * The page widget of the plugin.
+     * @return The page widget of the plugin
      */
     virtual SKGTabPage* getWidget();
 
@@ -174,10 +164,10 @@ public:
     virtual int getOrder() const;
 
     /**
-     * Must be implemented to know if a plugin must be display in context chooser.
+     * Must be implemented to know if a plugin must be display in pages chooser.
      * @return true of false (default = false)
      */
-    virtual bool isInContext() const;
+    virtual bool isInPagesChooser() const;
 
     /**
      * Must be implemented to know if this plugin is enabled
@@ -189,7 +179,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual QList<SKGInterfacePlugin::SKGAdvice> advices() const;
+    virtual SKGAdviceList advices() const;
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -208,9 +198,5 @@ private:
  * This plugin interface definition.
  */
 Q_DECLARE_INTERFACE(SKGInterfacePlugin, "skrooge.com.SKGInterfacePlugin/1.0");
-/**
- * Declare the class
- */
-Q_DECLARE_TYPEINFO(SKGInterfacePlugin::SKGAdvice, Q_PRIMITIVE_TYPE);
 
 #endif // SKGINTERFACEPLUGIN_H
