@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,6 +26,10 @@
 #include "skgbasegui_export.h"
 #include "skgtabpage.h"
 #include "skgbasegui_settings.h"
+#include "skginterfaceplugin.h"
+
+#include "ui_skgmainpanel_base.h"
+#include "ui_skgmainpanel_pref.h"
 
 #include <kparts/mainwindow.h>
 #include <ktabwidget.h>
@@ -33,10 +37,6 @@
 #include <ksystemtrayicon.h>
 #include <ktemporaryfile.h>
 
-#include "ui_skgmainpanel_base.h"
-#include "ui_skgmainpanel_pref.h"
-
-class SKGInterfacePlugin;
 class SKGDocument;
 class SKGZoomSelector;
 
@@ -93,8 +93,8 @@ public:
      * @param iCodec a valid QString to get the codec.
      * @return the file name
      */
-    static QString getSaveFileName(const QString & startDir = KUrl(), const QString & filter = QString(), QWidget * parent = 0,
-                                   const QString & caption = QString(), QString* iCodec = NULL);
+    static QString getSaveFileName(const QString& startDir = KUrl().url(), const QString& filter = QString(), QWidget* parent = 0,
+                                   const QString& caption = QString(), QString* iCodec = NULL);
 
     /**
      * Display an error message
@@ -166,14 +166,14 @@ public Q_SLOTS:
      * @param iIndex the index of the plugin
      * @return the plugin pointer. Can be NULL. Mustn't be deleted
      */
-    virtual SKGInterfacePlugin * getPluginByIndex(int iIndex);
+    virtual SKGInterfacePlugin* getPluginByIndex(int iIndex);
 
     /**
      * Return the plugin number by name
      * @param iName the name of the plugin
      * @return the plugin pointer. Can be NULL. Mustn't be deleted
      */
-    virtual SKGInterfacePlugin * getPluginByName(const QString& iName);
+    virtual SKGInterfacePlugin* getPluginByName(const QString& iName);
 
     /**
      * Get the label for normal message in status bar
@@ -205,6 +205,13 @@ public Q_SLOTS:
      */
     virtual SKGTabPage* currentPage() const;
 
+    /**
+     * Get a page
+     * @param iIndex an index
+     * @return the page
+     */
+    virtual SKGTabPage* page(int iIndex) const;
+
     /**
      * Get then number of pages
      * @return the number of pages
@@ -219,21 +226,21 @@ public Q_SLOTS:
 
     /**
      * Set the context item visibility
-     * @param iPage index of the page in the context chooser
+     * @param iPage index of the page in the pages chooser
      * @param iVisibility the visibility
      */
     virtual void setContextVisibility(int iPage, bool iVisibility);
 
     /**
      * Set the context item visibility
-     * @param iItem item in the context chooser
+     * @param iItem item in the pages chooser
      * @param iVisibility the visibility
      */
     virtual void setContextVisibility(QListWidgetItem* iItem, bool iVisibility);
 
     /**
      * Open a plugin in a page
-     * @param iPage index of the page in the context chooser
+     * @param iPage index of the page in the pages chooser
      * @param iNewPage to open a new page or not
      */
     virtual void openPage(int iPage, bool iNewPage);
@@ -245,9 +252,10 @@ public Q_SLOTS:
      * @param parameters parameters of the plugin
      * @param title title of the page
      * @param iID id of the new page
+     * @param iSetCurrent to set the new page as the current one
      * @return the opened tab
      */
-    virtual SKGTabPage* openPage(SKGInterfacePlugin* plugin, int index = -1, const QString& parameters = "", const QString& title = "", const QString& iID = "");
+    virtual SKGTabPage* openPage(SKGInterfacePlugin* plugin, int index = -1, const QString& parameters = "", const QString& title = "", const QString& iID = "", bool iSetCurrent = true);
 
     /**
      * Close a page
@@ -308,25 +316,36 @@ public Q_SLOTS:
      */
     virtual void optionsPreferences(const QString& iPluginName = "");
 
+    /**
+     * Get all advices
+     * @return the list of advices
+     */
+    virtual SKGAdviceList getAdvices() const;
+
 Q_SIGNALS:
     /**
      * This signal is sent when the current page change.
      */
     void currentPageChanged();
 
+    /**
+     * This signal is sent when settings change.
+     */
+    void settingsChanged();
+
 protected:
     /**
      * event
      * @param e event
      */
-    virtual void changeEvent(QEvent * e);
+    virtual void changeEvent(QEvent* e);
     /**
      * Event filtering
      * @param object object
      * @param event event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject *object, QEvent *event);
+    virtual bool eventFilter(QObject* object, QEvent* event);
 
 private Q_SLOTS:
     void showMenu(const QPoint& pos);
@@ -353,55 +372,67 @@ private Q_SLOTS:
     void onShowNextMenu();
     void onZoomChanged();
 
+    void onShowMenuBar();
+    void onShowButtonMenu();
+
     void actionHideContextItem();
     void actionShowAllContextItems();
+
+    void actionLockDocks();
+    void actionUnlockDocks();
 private:
     Q_DISABLE_COPY(SKGMainPanel);
     void setupActions();
     bool iconInSystemtray();
     void refreshTabPosition();
 
-    static int progressBarCallBack(int iPos, void* iProgressBar);
-    static bool naturalLessThan(const QString &s1, const QString &s2);
+    static int progressBarCallBack(int iPos, qint64 iTime, const QString& iName, void* iProgressBar);
+    static bool naturalLessThan(const QString& s1, const QString& s2);
+    static bool adviceLessThan(const SKGAdvice& s1, const SKGAdvice& s2);
+
 
     Ui::skgmainpanel_base ui;
     Ui::skgmainpanel_pref uipref;
 
-    SKGTabWidget *m_tabWidget;
+    SKGTabWidget* m_tabWidget;
     KSplashScreen* m_splashScreen;
 
     SKGDocument* m_currentDocument;
 
-    QList<SKGInterfacePlugin *> m_pluginsList;
+    QList<SKGInterfacePlugin*> m_pluginsList;
     QMap<QString, KAction*> m_registeredGlogalAction;
     QList<QWidget*> m_hiddenWidgets;
 
-    KMenu *m_contextMenu;
-    QAction *m_actHideContextItem;
-    QAction *m_actShowAllContextItems;
-    QAction *m_actDelete;
-    KAction *m_addTabAction;
-    KAction *m_tipOfDayAction;
-    KAction *m_closePageAction;
-    KAction *m_closeAllPagesAction;
-    KAction *m_closeAllOtherPagesAction;
-    KAction *m_saveDefaultStateAction;
-    KAction *m_resetDefaultStateAction;
-    KAction *m_overwriteBookmarkStateAction;
-    KAction *m_configureAction;
-    KAction *m_enableEditorAction;
+    KMenu* m_contextMenu;
+    QAction* m_actHideContextItem;
+    QAction* m_actShowAllContextItems;
+    QAction* m_actDelete;
+    KAction* m_addTabAction;
+    KAction* m_tipOfDayAction;
+    KAction* m_closePageAction;
+    KAction* m_closeAllPagesAction;
+    KAction* m_closeAllOtherPagesAction;
+    KAction* m_saveDefaultStateAction;
+    KAction* m_resetDefaultStateAction;
+    KAction* m_overwriteBookmarkStateAction;
+    KAction* m_configureAction;
+    KAction* m_enableEditorAction;
     KAction* m_fullScreenAction;
+    KAction* m_actLock;
+    KAction* m_actUnLock;
     KTemporaryFile m_tipsFile;
-    KPushButton *m_kCancelButton;
     KSystemTrayIcon* m_kSystemTrayIcon;
     QLabel* m_kNormalMessage;
     SKGZoomSelector* m_zoomSelector;
 
-    KToolBarPopupAction *m_previousAction;
-    KToolBarPopupAction *m_nextAction;
+    KToolBarPopupAction* m_previousAction;
+    KToolBarPopupAction* m_nextAction;
+    KToolBarPopupAction* m_buttonMenuAction;
+    KToggleAction* m_showMenuBarAction;
 
-    KMenu *m_previousMenu;
-    KMenu *m_nextMenu;
+    KMenu* m_previousMenu;
+    KMenu* m_nextMenu;
+    KMenu* m_buttonMenu;
 
     struct doublePointer {
         void* p1;
