@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -29,7 +29,7 @@
 #include <QAbstractItemModel>
 #include <QStringList>
 
-
+class QWidget;
 /**
  * The Table model managing SKGObjectBase
  */
@@ -54,7 +54,7 @@ public:
     SKGObjectModelBase(SKGDocument* iDocument,
                        const QString& iTable,
                        const QString& iWhereClause,
-                       QObject *parent = NULL,
+                       QWidget* parent = NULL,
                        const QString& iParentAttribute = "",
                        bool iResetOnCreation = true);
 
@@ -63,11 +63,6 @@ public:
      */
     virtual ~SKGObjectModelBase();
 
-    /**
-     * Refresh the model.
-     */
-    virtual void refresh();
-
     /**
      * Allows to block a refresh
      * @param iBlocked blocking status
@@ -86,7 +81,7 @@ public:
      * @param parent the parent
      * @return the number of row
      */
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
+    virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
 
     /**
      * Returns the index of the item in the model specified by the given row, column and parent index.
@@ -95,21 +90,21 @@ public:
      * @param parent parent
      * @return the index
      */
-    virtual QModelIndex index(int row, int column, const QModelIndex & parent = QModelIndex()) const;
+    virtual QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const;
 
     /**
      * Returns the parent of the model item with the given index, or QModelIndex() if it has no parent.
      * @param index index
      * @return the parent
      */
-    virtual QModelIndex parent(const QModelIndex & index) const;
+    virtual QModelIndex parent(const QModelIndex& index) const;
 
     /**
      * Returns the number of columns for the given parent.
      * @param parent the parent
      * @return the number of column
      */
-    virtual int columnCount(const QModelIndex & parent = QModelIndex()) const;
+    virtual int columnCount(const QModelIndex& parent = QModelIndex()) const;
 
     /**
      * Returns the data stored under the given role for the item referred to by the index.
@@ -117,21 +112,21 @@ public:
      * @param role the role
      * @return the returned value
      */
-    virtual QVariant data(const QModelIndex & index, int role = Qt::DisplayRole) const;
+    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
 
     /**
      * Returns the SKGObjectBase for the item referred to by the index.
      * @param index the index
      * @return the returned SKGObjectBase
      */
-    virtual SKGObjectBase getObject(const QModelIndex &index) const;
+    virtual SKGObjectBase getObject(const QModelIndex& index) const;
 
     /**
      * Returns the SKGObjectBase for the item referred to by the index.
      * @param index the index
      * @return the returned SKGObjectBase. Do not delete it !
      */
-    virtual SKGObjectBase* getObjectPointer(const QModelIndex &index) const;
+    virtual SKGObjectBase* getObjectPointer(const QModelIndex& index) const;
 
     /**
      * Returns the data for the given role and section in the header with the specified orientation.
@@ -147,7 +142,7 @@ public:
      * @param index index of the object
      * @return flags of the given index
      */
-    virtual Qt::ItemFlags flags(const QModelIndex &index) const;
+    virtual Qt::ItemFlags flags(const QModelIndex& index) const;
 
     /**
      * Sets the role data for the item at index to value. Returns true if successful; otherwise returns false.
@@ -156,7 +151,7 @@ public:
      * @param role role
      * @return
      */
-    virtual bool setData(const QModelIndex & index, const QVariant & value, int role = Qt::EditRole);
+    virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);
 
     /**
      * Return the index of the attribute, -1 if not found
@@ -184,13 +179,13 @@ public:
      * @param parent parent
      * @return true of false
      */
-    virtual bool canFetchMore(const QModelIndex & parent) const;
+    virtual bool canFetchMore(const QModelIndex& parent) const;
 
     /**
      * Set the table. Don't forget to do a reset after that.
      * @param iTable the table name
      */
-    virtual void setTable(const QString & iTable);
+    virtual void setTable(const QString& iTable);
 
     /**
      * Get table name
@@ -198,6 +193,25 @@ public:
      */
     virtual QString getTable() const;
 
+    /**
+     * Set the attribute used for grouping
+     * @param iAttribute the attibute name
+     */
+    virtual void setGroupBy(const QString& iAttribute = "");
+
+    /**
+     * Get the attribute used for grouping
+     * @return attibute name
+     */
+    virtual QString getGroupBy() const;
+
+    /**
+     * Get the attribute used for parent / child relationship
+     * @return attibute name
+     */
+    virtual QString getParentChildAttribute() const;
+
+
     /**
      * Get real table name
      * @return real table name
@@ -221,13 +235,14 @@ public:
      * @param iListAttribute the list of attributes. If the list is empty then the default list is set.
      * The format of this string is the following one: attribute name[|visibility Y or N[|size]];attribute name[|visibility Y or N[|size]];...
      */
-    virtual void setSupportedAttributes(const QStringList & iListAttribute);
+    virtual void setSupportedAttributes(const QStringList& iListAttribute);
 
     /**
      * Set the filter. Don't forget to do a reset after that.
      * @param iWhereClause the where clause
+     * @return true is the filter is really changed
      */
-    virtual void setFilter(const QString & iWhereClause);
+    virtual bool setFilter(const QString& iWhereClause);
 
     /**
      * Returns the actions supported by the data in this model.
@@ -260,7 +275,7 @@ public:
      * @param indexes the index object
      * @return the mime data
      */
-    virtual QMimeData* mimeData(const QModelIndexList &indexes) const;
+    virtual QMimeData* mimeData(const QModelIndexList& indexes) const;
 
     /**
      * Handles the data supplied by a drag and drop operation that ended with the given action.
@@ -274,10 +289,10 @@ public:
      * @param parent parent
      * @return true if the dropping was successful otherwise false.
      */
-    virtual bool dropMimeData(const QMimeData *data,
+    virtual bool dropMimeData(const QMimeData* data,
                               Qt::DropAction action,
                               int row, int column,
-                              const QModelIndex &parent);
+                              const QModelIndex& parent);
 Q_SIGNALS:
     /**
      * Emitted before reset
@@ -289,11 +304,11 @@ Q_SIGNALS:
      */
     void afterReset();
 
-protected Q_SLOTS:
+public Q_SLOTS:
     /**
-     * This method is called by refresh to build the cache (to improve performance)
+     * Refresh the model.
      */
-    virtual void buidCache();
+    virtual void refresh();
 
     /**
      * data are modified
@@ -301,7 +316,13 @@ protected Q_SLOTS:
      * @param iIdTransaction the id of the transaction for direct modifications of the table (update of modify objects is enough)
      *or 0 in case of modifications by impact (full table must be refreshed)
      */
-    virtual void dataModified(const QString& iTableName, int iIdTransaction);
+    virtual void dataModified(const QString& iTableName = "", int iIdTransaction = 0);
+
+protected Q_SLOTS:
+    /**
+     * This method is called by refresh to build the cache (to improve performance)
+     */
+    virtual void buidCache();
 
 protected:
 
@@ -325,6 +346,22 @@ protected:
      */
     bool m_isResetRealyNeeded;
 
+    /**
+     * Get the attribute value for grouping
+     * @param iObject the object
+     * @param iAttribute the attribute name
+     * @return the value of the attribute
+     */
+    virtual QString getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const;
+
+    /**
+     *The negative color
+     */
+    QVariant m_fontNegativeColor;
+
+private Q_SLOTS:
+    void pageChanged();
+
 private:
     Q_DISABLE_COPY(SKGObjectModelBase);
     void clear();
@@ -335,6 +372,7 @@ private:
     QString m_realTable;
     QString m_whereClause;
     QString m_parentAttribute;
+    QString m_groupby;
 
     SKGObjectBase::SKGListSKGObjectBase m_listObjects;
     QHash<int, SKGIntList> m_parentChildRelations;
