@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,6 +32,8 @@
 #include <kmenu.h>
 #include "skgmainpanel.h"
 
+class SKGObjectModelBase;
+class QSortFilterProxyModel;
 class SKGDocument;
 class QTimer;
 
@@ -59,7 +61,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGTreeView(QWidget *parent = 0);
+    SKGTreeView(QWidget* parent = 0);
 
     /**
      * Default Destructor
@@ -120,7 +122,7 @@ public:
      * Sets the current selection model to the given selectionModel.
      * @param selectionModel the selection model
      */
-    virtual void setSelectionModel(QItemSelectionModel * selectionModel);
+    virtual void setSelectionModel(QItemSelectionModel* selectionModel);
 
     /**
      * Insert a registered action
@@ -129,6 +131,14 @@ public:
      */
     virtual void insertGlobalAction(const QString& iRegisteredAction = "");
 
+    /**
+     * @brief Set model
+     *
+     * @param iModel the model
+     * @return void
+     **/
+    virtual void setModel(QAbstractItemModel* iModel);
+
 Q_SIGNALS:
     /**
      * Emitted when the empty area
@@ -153,7 +163,7 @@ protected:
      * If a valid item is pressed on it is made into the current item. This function emits the pressed() signal.
      * @param event the event
      */
-    virtual void mousePressEvent(QMouseEvent * event);
+    virtual void mousePressEvent(QMouseEvent* event);
 
 public Q_SLOTS:
     /**
@@ -234,6 +244,11 @@ public Q_SLOTS:
      */
     virtual void onSelectionChanged();
 
+    /**
+     * Expand all and resize columns if needed
+     */
+    virtual void expandAll();
+
 protected:
     /**
       * Event filtering
@@ -241,33 +256,40 @@ protected:
       * @param event event
       * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
       */
-    virtual bool eventFilter(QObject *object, QEvent *event);
+    virtual bool eventFilter(QObject* object, QEvent* event);
 
 private Q_SLOTS:
     void onExport();
-    void moveSection();
-    void setupHeaderMenu(bool iRefreshColumnSize = true);
+    void setupHeaderMenu();
+    void showHeaderMenu();
     void showHeaderMenu(const QPoint& pos);
     void showHideColumn();
     void switchAutoResize();
     void changeSchema();
     void saveDefaultClicked();
+    void groupByChanged(QAction*);
 
-    void onSortChanged();
+    void onSortChanged(int , Qt::SortOrder);
 
-    void onExpand(const QModelIndex & index);
-    void onCollapse(const QModelIndex & index);
+    void onExpand(const QModelIndex& index);
+    void onCollapse(const QModelIndex& index);
+    void onClick(const QModelIndex& index);
+    void copy();
 
 private:
     Q_DISABLE_COPY(SKGTreeView);
+    QStringList getCurrentSchema() const;
 
     KMenu* m_headerMenu;
     bool m_autoResize;
     QAction* m_actAutoResize;
+    KAction* m_actExpandAll;
+    KAction* m_actCollapseAll;
     SKGDocument* m_document;
     QString m_parameterName;
     QStringList m_selection;
     QStringList m_expandedNodes;
+    QString m_groupby;
 
     QTimer m_timerDelayedResize;
     QTimer m_timerSelectionChanged;
@@ -275,6 +297,11 @@ private:
     bool m_textResizable;
     int m_fontOriginalPointSize;
     int m_iconOriginalSize;
+
+    SKGObjectModelBase* m_model;
+    QSortFilterProxyModel* m_proxyModel;
+
+    SKGObjectBase::SKGListSKGObjectBase m_lastSelection;
 };
 
 #endif // SKGTREEVIEW_H
