@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -144,6 +144,14 @@ public:
         QString defaultvalue;       /**< The default value of the attribute */
     } ;
 
+    /**
+     * Search criteria
+     */
+    struct SKGSearchCriteria {
+        QChar mode;              /**< The mode '+' or '-' */
+        QStringList words;       /**< The list of words */
+    } ;
+
     /**
      * A list of SKGAttributeInfo ==> SKGAttributesList
      */
@@ -162,6 +170,13 @@ public:
         DUMP_TEXT  /**< To dump in DUMP_TEXT mode */
     };
 
+    /**
+     * Get list of search criteria of a string (exxample: +cat1 -abc +auto)
+     * @param iString a string to analyze
+     * @return the search criteria list
+     */
+    static QList<SKGSearchCriteria> stringToSearchCriterias(const QString& iString);
+
     /**
      * Get environment variable
      * @param iAttribute name of the variable
@@ -289,7 +304,7 @@ public:
      * @param iSeparator the csv separator
      * @param iCoteDefineBlock to indicate if the character double cote define a block
      * @param oRealSeparator the real csv separator. If the csv string is strictly all enclosed then oRealSeparator will contain the real separator
-     * @return the list of all values in this csv line
+     * @return the list of all values in this csv line. Return an empty list if some cote are opened and not closed
      */
     static QStringList splitCSVLine(const QString& iString, const QChar& iSeparator = ';', bool iCoteDefineBlock = true, QChar* oRealSeparator = NULL);
 
@@ -392,6 +407,15 @@ public:
      */
     static SKGError dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QStringList& oResult, SKGServices::DumpMode iMode = DUMP_TEXT);
 
+    /**
+     * Read a property file
+     * @param iFileName A file name
+     * @param oProperties the properties
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    static SKGError readPropertyFile(const QString& iFileName, QHash<QString, QString>& oProperties);
+
     /**
      * Return the current time in millisecond
      * @return current
@@ -416,6 +440,20 @@ public:
      */
     static int SKGSqlTraces;
 
+
+    /**
+     * Create a table with all values expressed in % of the column
+     * @param iTable table
+     */
+    static SKGStringListList getPercentTable(const SKGStringListList& iTable);
+
+    /**
+     * Create an historized table.
+     * Each column is the sum of previous ones
+     * @param iTable table
+     */
+    static SKGStringListList getHistorizedTable(const SKGStringListList& iTable);
+
 private:
     Q_DISABLE_COPY(SKGServices);
     static SKGError m_lastCallbackError;
