@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -47,7 +47,7 @@
  * @param argv arguments
  * @return return code
  */
-int main(int argc, char **argv)
+int main(int argc, char** argv)
 {
     KAboutData about("skrooge",
                      0,
@@ -78,7 +78,13 @@ int main(int argc, char **argv)
     KCmdLineArgs::addCmdLineOptions(options);
 
     int rc = 0;
-    if(!SKGUniqueApplication::start()) {
+    bool started = false;
+    if (!SKGServices::getenv("SKGNOTUNIQUE").isEmpty()) {
+        started = SKGUniqueApplication::start(SKGUniqueApplication::NonUniqueInstance);
+    } else {
+        started = SKGUniqueApplication::start();
+    }
+    if (!started) {
         fprintf(stderr, "Skrooge is already running!\n");
     } else {
         //Creating a main panel on a bank document
